%define releasedate	20140724
%define rel		3

%define major		4
%define minor		3
%define update		0
%define dotver		%{major}.%{minor}
%define sourcebasename	tbb%{major}%{minor}_%{releasedate}oss

%define libmajor	2
%define libname		%mklibname %{name} %{libmajor}
%define devname		%mklibname %{name} -d

Summary:	Library to abstract low-level threading details
Name:		tbb
Version:	%{dotver}
Release:	%mkrel 1.%{releasedate}.%{rel}
License:	GPLv2 with exceptions
Group:		Development/C++
URL:		http://threadingbuildingblocks.org/
Source0:	http://threadingbuildingblocks.org/sites/default/files/software_releases/source/tbb%{major}%{minor}_%{releasedate}oss_src.tgz

# These are downstream sources.
Source1:	tbb.pc
Source2:	tbbmalloc.pc
Source3:	tbbmalloc_proxy.pc

# (Fedora) Propagate CXXFLAGS variable into flags used when compiling C++.
# This so that %%optflags are respected.
Patch1:		tbb-4.3-mga-cxxflags.patch
# (Fedora) Replace mfence with xchg (for 32-bit builds only) so that TBB
# compiles and works supported hardware.  mfence was added with SSE2,
# which we still don't assume.
Patch2:		tbb-4.0-mfence.patch
# (Fedora) Don't snip -Wall from C++ flags.  Add -fno-strict-aliasing, as that
# uncovers some static-aliasing warnings.
# Related: https://bugzilla.redhat.com/show_bug.cgi?id=1037347
Patch3:		tbb-4.3-fdr-dont-snip-Wall.patch

BuildRequires:	libstdc++-devel
# We need "arch" and "hostname" binaries:
BuildRequires:	util-linux
BuildRequires:	net-tools

%description
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.

TBB requires fewer lines of code to achieve parallelism than other
threading models.  The applications you write are portable across
platforms.  Since the library is also inherently scalable, no code
maintenance is required as more processor cores become available.

%package -n %{libname}
Summary:	Library to abstract low-level threading details
Group:		System/Libraries
Obsoletes:	%{name} < 4.1-1.20121003.1

%description -n %{libname}
Threading Building Blocks (TBB) is a C++ runtime library that
abstracts the low-level threading details necessary for optimal
multi-core performance.  It uses common C++ templates and coding style
to eliminate tedious threading implementation work.

TBB requires fewer lines of code to achieve parallelism than other
threading models.  The applications you write are portable across
platforms.  Since the library is also inherently scalable, no code
maintenance is required as more processor cores become available.

%package -n %{devname}
Summary:	The Threading Building Blocks C++ headers and shared development libraries
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{name}-devel < 4.1-1.20121003.1

%description -n %{devname}
Header files and shared object symlinks for the Threading Building
Blocks (TBB) C++ libraries.

%package doc
Summary:	The Threading Building Blocks documentation
Group:		Documentation

%description doc
PDF documentation for the user of the Threading Building Block (TBB)
C++ library.


%prep
%setup -q -n %{sourcebasename}
%apply_patches

%build
%setup_compile_flags
%make tbb_build_prefix=obj

for file in %{SOURCE1} %{SOURCE2} %{SOURCE3}; do
    sed 's/_FEDORA_VERSION/%{major}.%{minor}.%{update}/' ${file} \
        > $(basename ${file})
done

%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_includedir}

pushd build/obj_release
    for file in libtbb{,malloc{,_proxy}}; do
        install -p -D -m 755 ${file}.so.%{libmajor} %{buildroot}%{_libdir}
        ln -s ${file}.so.%{libmajor} %{buildroot}%{_libdir}/${file}.so
    done
popd

pushd include
    find tbb -type f -name \*.h -exec \
        install -p -D -m 644 {} %{buildroot}/%{_includedir}/{} \
    \;
popd

for file in %{SOURCE1} %{SOURCE2} %{SOURCE3}; do
    install -p -D -m 644 $(basename ${file}) \
    %{buildroot}/%{_libdir}/pkgconfig/$(basename ${file})
done

%files -n %{libname}
%doc COPYING doc/Release_Notes.txt
%{_libdir}/lib*.so.%{libmajor}

%files -n %{devname}
%doc CHANGES
%{_includedir}/tbb/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%doc doc/html/*


%changelog
* Wed Oct 15 2014 umeabot <umeabot> 4.3-1.20140724.3.mga5
+ Revision: 741515
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.3-1.20140724.2.mga5
+ Revision: 689731
- Mageia 5 Mass Rebuild

* Wed Aug 27 2014 akien <akien> 4.3-1.20140724.1.mga5
+ Revision: 668602
- Version 4.3.0

* Sun Jun 15 2014 wally <wally> 4.1-1.20121003.1.mga5
+ Revision: 636629
- fix libification

* Thu Dec 13 2012 shlomif <shlomif> 4.1-1.20121003.mga3
+ Revision: 330401
- New version 4.1-something

* Wed Nov 14 2012 shlomif <shlomif> 4.0-5.20120408.mga3
+ Revision: 317951
- Correct the groups.
- Change to mkrel
- tbb package based on the Fedora package.


* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0-5.20120408
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun  7 2012 Petr Machata <pmachata@redhat.com> - 4.0-4.20120408
- Rebase to 4.0 update 4
- Refresh Getting_Started.pdf, Reference.pdf, Tutorial.pdf
- Provide pkg-config files
- Resolves: #825402

* Thu Apr 05 2012 Karsten Hopp <karsten@redhat.com> 4.0-3.20110809
- tbb builds now on PPC(64)

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0-2.20110809
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Oct 18 2011 Petr Machata <pmachata@redhat.com> - 4.0-1.20110809
- Rebase to 4.0
  - Port the mfence patch
  - Refresh the documentation bundle

* Tue Jul 26 2011 Petr Machata <pmachata@redhat.com> - 3.0-1.20110419
- Rebase to 3.0-r6
  - Port both patches
  - Package Design_Patterns.pdf
  - Thanks to Richard Shaw for initial rebase patch
- Resolves: #723043

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2-3.20090809
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jun 10 2010 Petr Machata <pmachata@redhat.com> - 2.2-2.20090809
- Replace mfence instruction with xchg to make it run on ia32-class
  machines without SSE2.
- Resolves: #600654

* Tue Nov  3 2009 Petr Machata <pmachata@redhat.com> - 2.2-1.20090809
- New upstream 2.2
- Resolves: #521571

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1-3.20080605
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1-2.20080605
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jun 13 2008 Petr Machata <pmachata@redhat.com> - 2.1-1.20080605
- New upstream 2.1
  - Drop soname patch, parallel make patch, and GCC 4.3 patch

* Wed Feb 13 2008 Petr Machata <pmachata@redhat.com> - 2.0-4.20070927
- Review fixes
  - Use updated URL
  - More timestamp preservation
- Initial import into Fedora CVS

* Mon Feb 11 2008 Petr Machata <pmachata@redhat.com> - 2.0-3.20070927
- Review fixes
  - Preserve timestamp of installed files
  - Fix soname not to contain "debug"

* Tue Feb  5 2008 Petr Machata <pmachata@redhat.com> - 2.0-2.20070927
- Review fixes
  - GCC 4.3 patchset
  - Add BR util-linux net-tools
  - Add full URL to Source0
  - Build in debug mode to work around problems with GCC 4.3

* Mon Dec 17 2007 Petr Machata <pmachata@redhat.com> - 2.0-1.20070927
- Initial package.
- Using SONAME patch from Debian.
